@@ -103,7 +103,8 @@ public partial class ChronoJumpWindow
 	ArrayList encoderCurves;
         Gtk.ListStore encoderListStore;
 
-	Thread encoderThread;
+	Thread encoderThreadCapture;
+	Thread encoderThreadR;
 	
 	Gdk.Pixmap encoder_capture_pixmap = null;
 
@@ -892,6 +893,22 @@ public partial class ChronoJumpWindow
 		Log.WriteLine("F22222222222222");
 	}
 	
+	private bool runEncoderCaptureCsharpCheckPort(string port) {
+		Log.WriteLine("00a 1");
+		SerialPort sp = new SerialPort(port);
+		Log.WriteLine("00b 1");
+		sp.BaudRate = 115200;
+		Log.WriteLine("00c 1");
+		try {
+			sp.Open();
+			sp.Close();
+		} catch {
+			return false;
+		}
+		Log.WriteLine("00d 1");
+		return true;
+	}
+
 	//private bool runEncoderCaptureCsharp(string title, EncoderStruct es, string port) 
 	private bool runEncoderCaptureCsharp(string title, int time, string outputData1, string port) 
 	{
@@ -900,13 +917,13 @@ public partial class ChronoJumpWindow
 		//int yrange = height;
 		double realHeight = 1000 * 2 * spin_encoder_capture_height.Value;
 		
-		Log.WriteLine("00a");
+		Log.WriteLine("00a 2");
 		SerialPort sp = new SerialPort(port);
-		Log.WriteLine("00b");
+		Log.WriteLine("00b 2");
 		sp.BaudRate = 115200;
-		Log.WriteLine("00c");
+		Log.WriteLine("00c 2");
 		sp.Open();
-		Log.WriteLine("00d");
+		Log.WriteLine("00d 2");
 			
 		encoderCaptureCountdown = time;
 		//int recordingTime = es.Ep.Time * 1000;
@@ -2112,10 +2129,17 @@ Log.WriteLine("RRR4");
 		if(mode == encoderModes.CAPTURE) {
 			//encoder_pulsebar_capture.Text = Catalog.GetString("Please, wait.");
 			Log.WriteLine("CCCCCCCCCCCCCCC");
-			encoderThread = new Thread(new ThreadStart(captureCsharp));
-			GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCapture));
-			Log.WriteLine("DDDDDDDDDDDDDDD");
-			encoderButtonsSensitive(encoderSensEnum.PROCESSINGCAPTURE);
+			if( runEncoderCaptureCsharpCheckPort(chronopicWin.GetEncoderPort()) ) {
+				encoderThreadCapture = new Thread(new ThreadStart(captureCsharp));
+				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCapture));
+				Log.WriteLine("DDDDDDDDDDDDDDD");
+				encoderButtonsSensitive(encoderSensEnum.PROCESSINGCAPTURE);
+				encoderThreadCapture.Start(); 
+			} else {
+				new DialogMessage(Constants.MessageTypes.WARNING, 
+					Catalog.GetString("Chronopic port is not configured."));
+				return;
+			}
 		} else if(mode == encoderModes.CALCULECURVES || mode == encoderModes.RECALCULATE_OR_LOAD) {
 			//image is inside (is smaller than) viewport
 			image_encoder_width = UtilGtk.WidgetWidth(viewport_image_encoder_capture)-5; 
@@ -2123,12 +2147,13 @@ Log.WriteLine("RRR4");
 
 //			encoder_pulsebar_capture.Text = Catalog.GetString("Please, wait.");
 			treeview_encoder_curves.Sensitive = false;
-			encoderThread = new Thread(new ThreadStart(encoderCreateCurvesGraphR));
+			encoderThreadR = new Thread(new ThreadStart(encoderCreateCurvesGraphR));
 			if(mode == encoderModes.CALCULECURVES)
 				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCalculeCurves));
 			else // mode == encoderModes.RECALCULATE_OR_LOAD
 				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderRecalculateOrLoad));
 			encoderButtonsSensitive(encoderSensEnum.PROCESSINGR);
+			encoderThreadR.Start(); 
 		} else { //encoderModes.ANALYZE
 			//the -3 is because image is inside (is smaller than) viewport
 			image_encoder_width = UtilGtk.WidgetWidth(viewport_image_encoder_analyze)-5; 
@@ -2136,18 +2161,18 @@ Log.WriteLine("RRR4");
 
 			encoder_pulsebar_analyze.Text = Catalog.GetString("Please, wait.");
 		
-			encoderThread = new Thread(new ThreadStart(analyze));
+			encoderThreadR = new Thread(new ThreadStart(analyze));
 			GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderAnalyze));
 			encoderButtonsSensitive(encoderSensEnum.PROCESSINGR);
+			encoderThreadR.Start(); 
 		}
-		encoderThread.Start(); 
 	}
 
 	//this is the only who was finish	
 	private bool pulseGTKEncoderCapture ()
 	{
 		Log.WriteLine("PPPPPPPPP");
-		if(! encoderThread.IsAlive || encoderProcessCancel || encoderProcessFinish) {
+		if(! encoderThreadCapture.IsAlive || encoderProcessCancel || encoderProcessFinish) {
 			finishPulsebar(encoderModes.CAPTURE);
 			Log.Write("dying");
 			return false;
@@ -2156,13 +2181,13 @@ Log.WriteLine("RRR4");
 		updateEncoderCaptureGraph();
 
 		Thread.Sleep (50);
-		Log.Write(encoderThread.ThreadState.ToString());
+		Log.Write("C:" + encoderThreadCapture.ThreadState.ToString());
 		return true;
 	}
 	
 	private bool pulseGTKEncoderCalculeCurves ()
 	{
-		if(! encoderThread.IsAlive || encoderProcessCancel) {
+		if(! encoderThreadR.IsAlive || encoderProcessCancel) {
 			if(encoderProcessCancel){
 				Util.CancelRScript = true;
 			}
@@ -2173,13 +2198,13 @@ Log.WriteLine("RRR4");
 		}
 		updatePulsebar(encoderModes.CALCULECURVES); //activity on pulsebar
 		Thread.Sleep (50);
-		Log.Write(encoderThread.ThreadState.ToString());
+		Log.Write("R:" + encoderThreadR.ThreadState.ToString());
 		return true;
 	}
 	
 	private bool pulseGTKEncoderRecalculateOrLoad ()
 	{
-		if(! encoderThread.IsAlive || encoderProcessCancel) {
+		if(! encoderThreadR.IsAlive || encoderProcessCancel) {
 			if(encoderProcessCancel){
 				Util.CancelRScript = true;
 			}
@@ -2190,13 +2215,13 @@ Log.WriteLine("RRR4");
 		}
 		updatePulsebar(encoderModes.CALCULECURVES); //activity on pulsebar
 		Thread.Sleep (50);
-		Log.Write(encoderThread.ThreadState.ToString());
+		Log.Write("R:" + encoderThreadR.ThreadState.ToString());
 		return true;
 	}
 	
 	private bool pulseGTKEncoderAnalyze ()
 	{
-		if(! encoderThread.IsAlive || encoderProcessCancel) {
+		if(! encoderThreadR.IsAlive || encoderProcessCancel) {
 			if(encoderProcessCancel){
 				Util.CancelRScript = true;
 			}
@@ -2207,7 +2232,7 @@ Log.WriteLine("RRR4");
 		}
 		updatePulsebar(encoderModes.ANALYZE); //activity on pulsebar
 		Thread.Sleep (50);
-		Log.Write(encoderThread.ThreadState.ToString());
+		Log.Write("R:" + encoderThreadR.ThreadState.ToString());
 		return true;
 	}
 	
@@ -2261,25 +2286,26 @@ Log.WriteLine("RRR4");
 				mode == encoderModes.RECALCULATE_OR_LOAD )
 		{
 			Log.WriteLine("ffffffinishPulsebarrrrr");
+			
 			if(encoderProcessCancel) {
 				//encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
 				encoderButtonsSensitive(encoderSensEnumStored);
 				encoder_pulsebar_capture.Text = Catalog.GetString("Cancelled");
 				if(notebook_encoder_capture.CurrentPage == 0 )
 					notebook_encoder_capture.NextPage();
+				encoder_pulsebar_capture.Fraction = 1;
 			}
-
-			if(
-				( mode == encoderModes.CALCULECURVES || 
-				  mode == encoderModes.RECALCULATE_OR_LOAD ) &&
-				notebook_encoder_capture.CurrentPage == 0 )
-					notebook_encoder_capture.NextPage();
-
-			if(mode == encoderModes.CAPTURE && encoderProcessFinish) {
+			else if(mode == encoderModes.CAPTURE && encoderProcessFinish) {
 				//encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
 				encoderButtonsSensitive(encoderSensEnumStored);
 				encoder_pulsebar_capture.Text = Catalog.GetString("Finished");
-			} else {
+			} 
+			else if(mode == encoderModes.CALCULECURVES || 
+					mode == encoderModes.RECALCULATE_OR_LOAD) {
+
+				if(notebook_encoder_capture.CurrentPage == 0)
+					notebook_encoder_capture.NextPage();
+
 				Pixbuf pixbuf = new Pixbuf (Util.GetEncoderGraphTempFileName()); //from a file
 				image_encoder_capture.Pixbuf = pixbuf;
 				encoderUpdateTreeView();
