@@ -27,7 +27,7 @@ public class ExecutingGraphData
 {
 	public Gtk.Button Button_cancel;
 	public Gtk.Button Button_finish;
-	public Gtk.TextView Textview_message;
+	public Gtk.Label Label_message;
 	public Gtk.Label Label_event_value;
 	public Gtk.Label Label_time_value;
 	public Gtk.ProgressBar Progressbar_event;
@@ -35,13 +35,13 @@ public class ExecutingGraphData
 	
 	public ExecutingGraphData(
 			Gtk.Button Button_cancel, Gtk.Button Button_finish, 
-			Gtk.TextView Textview_message,
+			Gtk.Label Label_message,
 			Gtk.Label Label_event_value, Gtk.Label Label_time_value,
 			Gtk.ProgressBar Progressbar_event, Gtk.ProgressBar Progressbar_time) 
 	{
 		this.Button_cancel =  Button_cancel;
 		this.Button_finish =  Button_finish;
-		this.Textview_message =  Textview_message;
+		this.Label_message =  Label_message;
 		this.Label_event_value =  Label_event_value;
 		this.Label_time_value =  Label_time_value;
 		this.Progressbar_event =  Progressbar_event;
