@@ -668,6 +668,13 @@ public class Util
 		return true;
 	}
 
+	public static bool IsEven(string myString) {
+		return IsEven(Convert.ToInt32(myString));
+	}
+	public static bool IsEven(int myInt) {
+		return (myInt % 2 == 0); //check if it's even (in spanish "par")
+	}
+
 	//Adapted from Mono. A developer's notebook. p 244
 	
 	//this is used in chronojump for working with the ports,
@@ -1069,8 +1076,9 @@ public class Util
 			//maybe R is not installed
 		}
 	}
-
-	public static void RunEncoderCapture(string title, EncoderStruct es, string port) {
+	
+	public static void RunEncoderCapturePython(string title, EncoderStruct es, string port) 
+	{
 		CancelRScript = false;
 
 		ProcessStartInfo pinfo;
@@ -1122,7 +1130,8 @@ public class Util
 		while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
 	}
 	
-	public static void RunEncoderGraph(string title, EncoderStruct es) {
+	public static void RunEncoderGraph(string title, EncoderStruct es) 
+	{
 		CancelRScript = false;
 
 		ProcessStartInfo pinfo;
@@ -1602,6 +1611,10 @@ public class Util
 			result = 0;
 		return result;
 	}
+	
+	public static double DivideSafeFraction (int val1, int val2) {
+		return DivideSafeFraction(Convert.ToDouble(val1), Convert.ToDouble(val2));
+	}
 
 	/*
 	//converts all values to positive
